Random String Maker is a simple python package I made for fun.
The usage is as following:

variable you want to be assigned a random string = randomstring.ranstr((how long do you want your string to be), (do you want to use numbers in your string?, give it a boolean value), (do you want to use lower case letters in your string?, give it a boolean value), (do you want to use special characters in your string?, give a boolean value), (do you want to use capital letters in your string?, give it a boolean value))

Enjoy.